package org.eclipse.ui.tutorials.rcp.part3;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PartInitException;

public class SwitchIconAction extends Action {
	
	private final IWorkbenchWindow window;
	private int instanceNum = 0;
	private ToolBarManager tbMgr;
	
	public SwitchIconAction(IWorkbenchWindow window, String label) {
		this.window = window;
        setText(label);
        // The id is used to refer to the action in a menu or toolbar
		setId(ICommandIds.CMD_SWITCH_ICON);
        // Associate the action with a pre-defined command, to allow key bindings.
		setActionDefinitionId(ICommandIds.CMD_SWITCH_ICON);
		setImageDescriptor(org.eclipse.ui.tutorials.rcp.part3.Part3Plugin.getImageDescriptor("/icons/sample.gif"));
	}
	
	public void setToolBarMgr(ToolBarManager tbmgr)
	{
		tbMgr = tbmgr;
	}
	
	public void run() 
	{
        MessageDialog.openInformation(window.getShell(), "Icon", "switch");
        
        IContributionItem[] tbItems = tbMgr.getItems();
        if( tbItems != null && tbItems.length > 0 )
        {
            for( IContributionItem item : tbItems )
            {
                if( item instanceof ActionContributionItem )
                {
                    IAction action = ( (ActionContributionItem) item ).getAction();
                    // find the 1st action and change it's icon to 32x32
                    ImageDescriptor desc = org.eclipse.ui.tutorials.rcp.part3.Part3Plugin.getImageDescriptor(
                            "/icons/default_search_32.png" ); //$NON-NLS-1$
                    action.setImageDescriptor( desc );
                    action.setHoverImageDescriptor( desc );

                    break;
                }
            }
        }
        tbMgr.update( true );
	}
}
